@@ -6,4 +6,4 @@
 mkdir -p /tmp/runtime-pyspreadci
 export XDG_RUNTIME_DIR=/tmp/runtime-pyspreadci
 
-py.test-3
+pytest -k 'not test_get_header and not test_csv_reader'
